@@ -578,8 +578,14 @@ def bidirectional_copy(a,b):
   while len(rfds) > 0 or len(wfds) > 0:
     try:
       rd,wr,_ = select.select(rfds,wfds,[])
-    except select.error:
-      continue
+    except select.error as e:
+      if e.errno == errno.EAGAIN:
+        # loop and try again
+        continue
+      elif e.errno == errno.EBADF:
+        fatal("bidirectional_copy failed with EBADF (Bad file descriptor)")
+      else:
+        fatal("bidirectional_copy failed with error %d" + str(e.errno))
     if af in rd:
       #verbose('af is readable')
       #os.write(1,'>')
